@@ -21,8 +21,7 @@
 #include "sessionlogger_p.h"
 
 #include "kimap_debug.h"
-
-#include <unistd.h> // for getpid()
+#include <QCoreApplication>
 
 using namespace KIMAP;
 
@@ -33,8 +32,10 @@ SessionLogger::SessionLogger()
     m_id = ++nextId;
 
     m_file.setFileName(QLatin1String(qgetenv("KIMAP_LOGFILE"))
-                       + QLatin1Char('.') + QString::number(getpid())
-                       + QLatin1Char('.') + QString::number(m_id));
+                       + QLatin1Char('.')
+                       + QString::number(QCoreApplication::applicationPid())
+                       + QLatin1Char('.')
+                       + QString::number(m_id));
     if (!m_file.open(QFile::WriteOnly)) {
         qCWarning(KIMAP_LOG) << "Could not open log file for writing:" << m_file.fileName();
     }
